DirectSum

Struct DirectSum 

pub struct DirectSum { /* private fields */ }
The DirectSum simulation method is the most intuitive way to process a molecular dynamics simulation. It bases the computation on the Direct Sum method.

Newton Pair Optimization: The only optimization DirectSum performs is avoiding computing the same pair of particles twice.