Vec3

Struct Vec3 

pub struct Vec3<T = f64> {
    pub x: T,
    pub y: T,
    pub z: T,
}
A struct representing a three-dimensional mathematical vector. These are used to represent particle information, such as position or velocity, in three-dimensional space.

Fields

x: Ty: Tz: T

Implementations

Source

impl<T> Vec3<T>

pub fn new(x: T, y: T, z: T) -> Self

Creates a new Vec3 instance with the given x, y, and z components.

Example
use moldyn_core::Vec3;

let v: Vec3<f64> = Vec3::new(1.0, 2.0, 3.0);
let w: Vec3<i32> = Vec3::new(1, 2, 3);

assert_eq!(v.x, 1.0);
assert_eq!(v.y, 2.0);
assert_eq!(v.z, 3.0);
assert_eq!(w.x, 1);
assert_eq!(w.y, 2);
assert_eq!(w.z, 3);
pub fn zero() -> Self
where T: Default,

Creates a new Vec3 instance with all components set to zero. Requires that the generic type implements the Default trait.

pub fn map<U, F>(self, f: F) -> Vec3<U>
where F: Fn(T) -> U,

Maps the individual components of the Vec3 instance to a new type with the provided lambda expression.

Source

impl Vec3<u8>

pub fn dot(&self, other: &Self) -> u8

Creates the dot product of two Vec3 instances of the same primitive type.

Example
use moldyn_core::Vec3;

let v = Vec3::new(1.0, 2.0, 3.0);
let w = Vec3::new(4.0, 5.0, 6.0);

// TODO think about example output
pub fn cross(&self, other: &Self) -> Self

Creates the cross product of two Vec3 instances of the same primitive type.

Example
use moldyn_core::Vec3;

let v = Vec3::new(1.0, 2.0, 3.0);
let w = Vec3::new(4.0, 5.0, 6.0);

// TODO think about example output
pub fn length(&self) -> f64

Computes the length (magnitude) of the Vec3 instance.

Example
use moldyn_core::Vec3;

let v : Vec3 < u8 > = Vec3 :: < u8 > :: new(2.0 as u8, 2.0 as u8, 1.0 as u8);

assert_eq!(v.length(), 3.0);
pub fn length2(&self) -> u8

TODO: rethink: old codebase became buggy because we used the wrong method.

pub fn normal(&self) -> Option<Self>

Normalizes the Vec3 instance to have a length of 1, returning an option containing a new Vec3 instance. If the original vector is zero-length, returns None to avoid division by zero.

Note: I’ve made this decision with the intention of propagating divisions by zero upwards the stack. I do not know if this will turn out to be useful.

Source

impl Vec3<u16>

pub fn dot(&self, other: &Self) -> u16

Creates the dot product of two Vec3 instances of the same primitive type.

Example
use moldyn_core::Vec3;

let v = Vec3::new(1.0, 2.0, 3.0);
let w = Vec3::new(4.0, 5.0, 6.0);

// TODO think about example output
pub fn cross(&self, other: &Self) -> Self

Creates the cross product of two Vec3 instances of the same primitive type.

Example
use moldyn_core::Vec3;

let v = Vec3::new(1.0, 2.0, 3.0);
let w = Vec3::new(4.0, 5.0, 6.0);

// TODO think about example output
pub fn length(&self) -> f64

Computes the length (magnitude) of the Vec3 instance.

Example
use moldyn_core::Vec3;

let v : Vec3 < u16 > = Vec3 :: < u16 > ::
new(2.0 as u16, 2.0 as u16, 1.0 as u16);

assert_eq!(v.length(), 3.0);
pub fn length2(&self) -> u16

TODO: rethink: old codebase became buggy because we used the wrong method.

pub fn normal(&self) -> Option<Self>

Normalizes the Vec3 instance to have a length of 1, returning an option containing a new Vec3 instance. If the original vector is zero-length, returns None to avoid division by zero.

Note: I’ve made this decision with the intention of propagating divisions by zero upwards the stack. I do not know if this will turn out to be useful.

Source

impl Vec3<u32>

pub fn dot(&self, other: &Self) -> u32

Creates the dot product of two Vec3 instances of the same primitive type.

Example
use moldyn_core::Vec3;

let v = Vec3::new(1.0, 2.0, 3.0);
let w = Vec3::new(4.0, 5.0, 6.0);

// TODO think about example output
pub fn cross(&self, other: &Self) -> Self

Creates the cross product of two Vec3 instances of the same primitive type.

Example
use moldyn_core::Vec3;

let v = Vec3::new(1.0, 2.0, 3.0);
let w = Vec3::new(4.0, 5.0, 6.0);

// TODO think about example output
pub fn length(&self) -> f64

Computes the length (magnitude) of the Vec3 instance.

Example
use moldyn_core::Vec3;

let v : Vec3 < u32 > = Vec3 :: < u32 > ::
new(2.0 as u32, 2.0 as u32, 1.0 as u32);

assert_eq!(v.length(), 3.0);
pub fn length2(&self) -> u32

TODO: rethink: old codebase became buggy because we used the wrong method.

pub fn normal(&self) -> Option<Self>

Normalizes the Vec3 instance to have a length of 1, returning an option containing a new Vec3 instance. If the original vector is zero-length, returns None to avoid division by zero.

Note: I’ve made this decision with the intention of propagating divisions by zero upwards the stack. I do not know if this will turn out to be useful.

Source

impl Vec3<u64>

pub fn dot(&self, other: &Self) -> u64

Creates the dot product of two Vec3 instances of the same primitive type.

Example
use moldyn_core::Vec3;

let v = Vec3::new(1.0, 2.0, 3.0);
let w = Vec3::new(4.0, 5.0, 6.0);

// TODO think about example output
pub fn cross(&self, other: &Self) -> Self

Creates the cross product of two Vec3 instances of the same primitive type.

Example
use moldyn_core::Vec3;

let v = Vec3::new(1.0, 2.0, 3.0);
let w = Vec3::new(4.0, 5.0, 6.0);

// TODO think about example output
pub fn length(&self) -> f64

Computes the length (magnitude) of the Vec3 instance.

Example
use moldyn_core::Vec3;

let v : Vec3 < u64 > = Vec3 :: < u64 > ::
new(2.0 as u64, 2.0 as u64, 1.0 as u64);

assert_eq!(v.length(), 3.0);
pub fn length2(&self) -> u64

TODO: rethink: old codebase became buggy because we used the wrong method.

pub fn normal(&self) -> Option<Self>

Normalizes the Vec3 instance to have a length of 1, returning an option containing a new Vec3 instance. If the original vector is zero-length, returns None to avoid division by zero.

Note: I’ve made this decision with the intention of propagating divisions by zero upwards the stack. I do not know if this will turn out to be useful.

Source

impl Vec3<u128>

pub fn dot(&self, other: &Self) -> u128

Creates the dot product of two Vec3 instances of the same primitive type.

Example
use moldyn_core::Vec3;

let v = Vec3::new(1.0, 2.0, 3.0);
let w = Vec3::new(4.0, 5.0, 6.0);

// TODO think about example output
pub fn cross(&self, other: &Self) -> Self

Creates the cross product of two Vec3 instances of the same primitive type.

Example
use moldyn_core::Vec3;

let v = Vec3::new(1.0, 2.0, 3.0);
let w = Vec3::new(4.0, 5.0, 6.0);

// TODO think about example output
pub fn length(&self) -> f64

Computes the length (magnitude) of the Vec3 instance.

Example
use moldyn_core::Vec3;

let v : Vec3 < u128 > = Vec3 :: < u128 > ::
new(2.0 as u128, 2.0 as u128, 1.0 as u128);

assert_eq!(v.length(), 3.0);
pub fn length2(&self) -> u128

TODO: rethink: old codebase became buggy because we used the wrong method.

pub fn normal(&self) -> Option<Self>

Normalizes the Vec3 instance to have a length of 1, returning an option containing a new Vec3 instance. If the original vector is zero-length, returns None to avoid division by zero.

Note: I’ve made this decision with the intention of propagating divisions by zero upwards the stack. I do not know if this will turn out to be useful.

Source

impl Vec3<usize>

pub fn dot(&self, other: &Self) -> usize

Creates the dot product of two Vec3 instances of the same primitive type.

Example
use moldyn_core::Vec3;

let v = Vec3::new(1.0, 2.0, 3.0);
let w = Vec3::new(4.0, 5.0, 6.0);

// TODO think about example output
pub fn cross(&self, other: &Self) -> Self

Creates the cross product of two Vec3 instances of the same primitive type.

Example
use moldyn_core::Vec3;

let v = Vec3::new(1.0, 2.0, 3.0);
let w = Vec3::new(4.0, 5.0, 6.0);

// TODO think about example output
pub fn length(&self) -> f64

Computes the length (magnitude) of the Vec3 instance.

Example
use moldyn_core::Vec3;

let v : Vec3 < usize > = Vec3 :: < usize > ::
new(2.0 as usize, 2.0 as usize, 1.0 as usize);

assert_eq!(v.length(), 3.0);
pub fn length2(&self) -> usize

TODO: rethink: old codebase became buggy because we used the wrong method.

pub fn normal(&self) -> Option<Self>

Normalizes the Vec3 instance to have a length of 1, returning an option containing a new Vec3 instance. If the original vector is zero-length, returns None to avoid division by zero.

Note: I’ve made this decision with the intention of propagating divisions by zero upwards the stack. I do not know if this will turn out to be useful.

Source

impl Vec3<i8>

pub fn dot(&self, other: &Self) -> i8

Creates the dot product of two Vec3 instances of the same primitive type.

Example
use moldyn_core::Vec3;

let v = Vec3::new(1.0, 2.0, 3.0);
let w = Vec3::new(4.0, 5.0, 6.0);

// TODO think about example output
pub fn cross(&self, other: &Self) -> Self

Creates the cross product of two Vec3 instances of the same primitive type.

Example
use moldyn_core::Vec3;

let v = Vec3::new(1.0, 2.0, 3.0);
let w = Vec3::new(4.0, 5.0, 6.0);

// TODO think about example output
pub fn length(&self) -> f64

Computes the length (magnitude) of the Vec3 instance.

Example
use moldyn_core::Vec3;

let v : Vec3 < i8 > = Vec3 :: < i8 > :: new(2.0 as i8, 2.0 as i8, 1.0 as i8);

assert_eq!(v.length(), 3.0);
pub fn length2(&self) -> i8

TODO: rethink: old codebase became buggy because we used the wrong method.

pub fn normal(&self) -> Option<Self>

Normalizes the Vec3 instance to have a length of 1, returning an option containing a new Vec3 instance. If the original vector is zero-length, returns None to avoid division by zero.

Note: I’ve made this decision with the intention of propagating divisions by zero upwards the stack. I do not know if this will turn out to be useful.

Source

impl Vec3<i16>

pub fn dot(&self, other: &Self) -> i16

Creates the dot product of two Vec3 instances of the same primitive type.

Example
use moldyn_core::Vec3;

let v = Vec3::new(1.0, 2.0, 3.0);
let w = Vec3::new(4.0, 5.0, 6.0);

// TODO think about example output
pub fn cross(&self, other: &Self) -> Self

Creates the cross product of two Vec3 instances of the same primitive type.

Example
use moldyn_core::Vec3;

let v = Vec3::new(1.0, 2.0, 3.0);
let w = Vec3::new(4.0, 5.0, 6.0);

// TODO think about example output
pub fn length(&self) -> f64

Computes the length (magnitude) of the Vec3 instance.

Example
use moldyn_core::Vec3;

let v : Vec3 < i16 > = Vec3 :: < i16 > ::
new(2.0 as i16, 2.0 as i16, 1.0 as i16);

assert_eq!(v.length(), 3.0);
pub fn length2(&self) -> i16

TODO: rethink: old codebase became buggy because we used the wrong method.

pub fn normal(&self) -> Option<Self>

Normalizes the Vec3 instance to have a length of 1, returning an option containing a new Vec3 instance. If the original vector is zero-length, returns None to avoid division by zero.

Note: I’ve made this decision with the intention of propagating divisions by zero upwards the stack. I do not know if this will turn out to be useful.

Source

impl Vec3<i32>

pub fn dot(&self, other: &Self) -> i32

Creates the dot product of two Vec3 instances of the same primitive type.

Example
use moldyn_core::Vec3;

let v = Vec3::new(1.0, 2.0, 3.0);
let w = Vec3::new(4.0, 5.0, 6.0);

// TODO think about example output
pub fn cross(&self, other: &Self) -> Self

Creates the cross product of two Vec3 instances of the same primitive type.

Example
use moldyn_core::Vec3;

let v = Vec3::new(1.0, 2.0, 3.0);
let w = Vec3::new(4.0, 5.0, 6.0);

// TODO think about example output
pub fn length(&self) -> f64

Computes the length (magnitude) of the Vec3 instance.

Example
use moldyn_core::Vec3;

let v : Vec3 < i32 > = Vec3 :: < i32 > ::
new(2.0 as i32, 2.0 as i32, 1.0 as i32);

assert_eq!(v.length(), 3.0);
pub fn length2(&self) -> i32

TODO: rethink: old codebase became buggy because we used the wrong method.

pub fn normal(&self) -> Option<Self>

Normalizes the Vec3 instance to have a length of 1, returning an option containing a new Vec3 instance. If the original vector is zero-length, returns None to avoid division by zero.

Note: I’ve made this decision with the intention of propagating divisions by zero upwards the stack. I do not know if this will turn out to be useful.

Source

impl Vec3<i64>

pub fn dot(&self, other: &Self) -> i64

Creates the dot product of two Vec3 instances of the same primitive type.

Example
use moldyn_core::Vec3;

let v = Vec3::new(1.0, 2.0, 3.0);
let w = Vec3::new(4.0, 5.0, 6.0);

// TODO think about example output
pub fn cross(&self, other: &Self) -> Self

Creates the cross product of two Vec3 instances of the same primitive type.

Example
use moldyn_core::Vec3;

let v = Vec3::new(1.0, 2.0, 3.0);
let w = Vec3::new(4.0, 5.0, 6.0);

// TODO think about example output
pub fn length(&self) -> f64

Computes the length (magnitude) of the Vec3 instance.

Example
use moldyn_core::Vec3;

let v : Vec3 < i64 > = Vec3 :: < i64 > ::
new(2.0 as i64, 2.0 as i64, 1.0 as i64);

assert_eq!(v.length(), 3.0);
pub fn length2(&self) -> i64

TODO: rethink: old codebase became buggy because we used the wrong method.

pub fn normal(&self) -> Option<Self>

Normalizes the Vec3 instance to have a length of 1, returning an option containing a new Vec3 instance. If the original vector is zero-length, returns None to avoid division by zero.

Note: I’ve made this decision with the intention of propagating divisions by zero upwards the stack. I do not know if this will turn out to be useful.

Source

impl Vec3<i128>

pub fn dot(&self, other: &Self) -> i128

Creates the dot product of two Vec3 instances of the same primitive type.

Example
use moldyn_core::Vec3;

let v = Vec3::new(1.0, 2.0, 3.0);
let w = Vec3::new(4.0, 5.0, 6.0);

// TODO think about example output
pub fn cross(&self, other: &Self) -> Self

Creates the cross product of two Vec3 instances of the same primitive type.

Example
use moldyn_core::Vec3;

let v = Vec3::new(1.0, 2.0, 3.0);
let w = Vec3::new(4.0, 5.0, 6.0);

// TODO think about example output
pub fn length(&self) -> f64

Computes the length (magnitude) of the Vec3 instance.

Example
use moldyn_core::Vec3;

let v : Vec3 < i128 > = Vec3 :: < i128 > ::
new(2.0 as i128, 2.0 as i128, 1.0 as i128);

assert_eq!(v.length(), 3.0);
pub fn length2(&self) -> i128

TODO: rethink: old codebase became buggy because we used the wrong method.

pub fn normal(&self) -> Option<Self>

Normalizes the Vec3 instance to have a length of 1, returning an option containing a new Vec3 instance. If the original vector is zero-length, returns None to avoid division by zero.

Note: I’ve made this decision with the intention of propagating divisions by zero upwards the stack. I do not know if this will turn out to be useful.

Source

impl Vec3<isize>

pub fn dot(&self, other: &Self) -> isize

Creates the dot product of two Vec3 instances of the same primitive type.

Example
use moldyn_core::Vec3;

let v = Vec3::new(1.0, 2.0, 3.0);
let w = Vec3::new(4.0, 5.0, 6.0);

// TODO think about example output
pub fn cross(&self, other: &Self) -> Self

Creates the cross product of two Vec3 instances of the same primitive type.

Example
use moldyn_core::Vec3;

let v = Vec3::new(1.0, 2.0, 3.0);
let w = Vec3::new(4.0, 5.0, 6.0);

// TODO think about example output
pub fn length(&self) -> f64

Computes the length (magnitude) of the Vec3 instance.

Example
use moldyn_core::Vec3;

let v : Vec3 < isize > = Vec3 :: < isize > ::
new(2.0 as isize, 2.0 as isize, 1.0 as isize);

assert_eq!(v.length(), 3.0);
pub fn length2(&self) -> isize

TODO: rethink: old codebase became buggy because we used the wrong method.

pub fn normal(&self) -> Option<Self>

Normalizes the Vec3 instance to have a length of 1, returning an option containing a new Vec3 instance. If the original vector is zero-length, returns None to avoid division by zero.

Note: I’ve made this decision with the intention of propagating divisions by zero upwards the stack. I do not know if this will turn out to be useful.

Source

impl Vec3<f32>

pub fn dot(&self, other: &Self) -> f32

Creates the dot product of two Vec3 instances of the same primitive type.

Example
use moldyn_core::Vec3;

let v = Vec3::new(1.0, 2.0, 3.0);
let w = Vec3::new(4.0, 5.0, 6.0);

// TODO think about example output
pub fn cross(&self, other: &Self) -> Self

Creates the cross product of two Vec3 instances of the same primitive type.

Example
use moldyn_core::Vec3;

let v = Vec3::new(1.0, 2.0, 3.0);
let w = Vec3::new(4.0, 5.0, 6.0);

// TODO think about example output
pub fn length(&self) -> f64

Computes the length (magnitude) of the Vec3 instance.

Example
use moldyn_core::Vec3;

let v : Vec3 < f32 > = Vec3 :: < f32 > ::
new(2.0 as f32, 2.0 as f32, 1.0 as f32);

assert_eq!(v.length(), 3.0);
pub fn length2(&self) -> f32

TODO: rethink: old codebase became buggy because we used the wrong method.

pub fn normal(&self) -> Option<Self>

Normalizes the Vec3 instance to have a length of 1, returning an option containing a new Vec3 instance. If the original vector is zero-length, returns None to avoid division by zero.

Note: I’ve made this decision with the intention of propagating divisions by zero upwards the stack. I do not know if this will turn out to be useful.

Source

impl Vec3<f64>

pub fn dot(&self, other: &Self) -> f64

Creates the dot product of two Vec3 instances of the same primitive type.

Example
use moldyn_core::Vec3;

let v = Vec3::new(1.0, 2.0, 3.0);
let w = Vec3::new(4.0, 5.0, 6.0);

// TODO think about example output
pub fn cross(&self, other: &Self) -> Self

Creates the cross product of two Vec3 instances of the same primitive type.

Example
use moldyn_core::Vec3;

let v = Vec3::new(1.0, 2.0, 3.0);
let w = Vec3::new(4.0, 5.0, 6.0);

// TODO think about example output
pub fn length(&self) -> f64

Computes the length (magnitude) of the Vec3 instance.

Example
use moldyn_core::Vec3;

let v : Vec3 < f64 > = Vec3 :: < f64 > ::
new(2.0 as f64, 2.0 as f64, 1.0 as f64);

assert_eq!(v.length(), 3.0);
pub fn length2(&self) -> f64

TODO: rethink: old codebase became buggy because we used the wrong method.

pub fn normal(&self) -> Option<Self>

Normalizes the Vec3 instance to have a length of 1, returning an option containing a new Vec3 instance. If the original vector is zero-length, returns None to avoid division by zero.

Note: I’ve made this decision with the intention of propagating divisions by zero upwards the stack. I do not know if this will turn out to be useful.